import { Renderer, RootRenderer, RenderComponentType, AnimationPlayer } from '@angular/core';
import { EventManager, AnimationDriver } from '@angular/platform-browser';
import { SharedCustomStylesHost } from './shared-custom-styles-host';
/**
 * The polymer renderer takes care of supporting angular > 2.2 shady DOM
 *
 * The problem:
 * Starting from v2.2, Angular uses direct DOM rendering in browser. BrowserDomAdapter is not invoked by Renderer.
 * Therefore, changing the default BrowserDomAdapter to PolymerDomAdapter trick is not helpful anymore.
 * The issue breaks setting Light DOM for Polymer elements in Shady DOM mode of Polymer v1.0.
 *
 * The solution:
 * Instead of PolymerDomAdapter, we created the PolymerRenderer by implementing the Renderer interface.
 * The PolymerRenderer calls Polymer.dom APIs instead of DOM methods. In order to make Angular use the PolymerRenderer,
 * we need to define and export custom platforms, i.e., platformPolymer and platformPolymerDynamic.
 * In practice, developers will have to switch the imports in their main.ts files to use our custom Polymer platforms
 * instead of the default platformBrowser and platformBrowserDynamic.
 *
 * DefaultPolymerRenderer used for ViewEncapsulation.None, other style incapsulation modes are implemented in subclasses.
 */
export declare class DefaultPolymerRenderer implements Renderer {
    private _eventManager;
    private _animationDriver;
    constructor(_eventManager: EventManager, _animationDriver: AnimationDriver);
    selectRootElement(selectorOrElement: string | Element): Element;
    createElement(parent: Element | DocumentFragment, name: string): Element;
    createViewRoot(hostElement: Element): Element | DocumentFragment;
    createTemplateAnchor(parent: Element | DocumentFragment): Element;
    createText(parent: Element | DocumentFragment, value: string): Text;
    projectNodes(parent: Element | DocumentFragment, nodes: Node[]): void;
    attachViewAfter(node: Node, viewRootNodes: Node[]): void;
    detachView(viewRootNodes: Node[]): void;
    destroyView(hostElement: Element | DocumentFragment, viewAllNodes: Node[]): void;
    listen(renderElement: any, name: string, callback: Function): Function;
    listenGlobal(target: string, name: string, callback: Function): Function;
    setElementProperty(renderElement: Element | DocumentFragment, propertyName: string, propertyValue: any): void;
    setElementAttribute(renderElement: Element | DocumentFragment, attributeName: string, attributeValue: string): void;
    setBindingDebugInfo(renderElement: Element, propertyName: string, propertyValue: string): void;
    setElementClass(renderElement: Element, className: string, isAdd: boolean): void;
    setElementStyle(renderElement: HTMLElement, styleName: string, styleValue: string): void;
    invokeElementMethod(renderElement: Element, methodName: string, args: any[]): void;
    setText(renderNode: Text, text: string): void;
    animate(element: any, startingStyles: any, keyframes: any[], duration: number, delay: number, easing: string, previousPlayers?: AnimationPlayer[]): AnimationPlayer;
}
/**
 * Polymer renderer for ViewEncapsulation.Emulated styles encapsulation mode (defaultmode)
 */
export declare class EmulatedEncapsulationPolymerRenderer extends DefaultPolymerRenderer {
    private _contentAttr;
    private _hostAttr;
    constructor(eventManager: EventManager, animationDriver: AnimationDriver, sharedCustomStylesHost: SharedCustomStylesHost, componentType: RenderComponentType, styleShimId: string);
    createViewRoot(hostElement: Element): Element | DocumentFragment;
    createElement(parent: Element | DocumentFragment, name: string): Element;
}
/**
 * Polymer renderer for ViewEncapsulation.Native styles encapsulation mode
 */
export declare class ShadowDomPolymerRenderer extends DefaultPolymerRenderer {
    private sharedCustomStylesHost;
    private _shadowRoot;
    private _styles;
    constructor(eventManager: EventManager, animationDriver: AnimationDriver, sharedCustomStylesHost: SharedCustomStylesHost, componentType: RenderComponentType, styleShimId: string);
    createViewRoot(hostElement: Element): Element | DocumentFragment;
    destroyView(hostElement: Element | DocumentFragment, viewAllNodes: Node[]): void;
}
export declare class PolymerRootRenderer implements RootRenderer {
    document: any;
    eventManager: EventManager;
    sharedCustomStylesHost: SharedCustomStylesHost;
    animationDriver: AnimationDriver;
    appId: string;
    protected registeredComponents: Map<string, Renderer>;
    private defaultRenderer;
    constructor(document: any, eventManager: EventManager, sharedCustomStylesHost: SharedCustomStylesHost, animationDriver: AnimationDriver, appId: string);
    renderComponent(componentType: RenderComponentType): Renderer;
}
